@@ -20,6 +20,9 @@ use Search::Xapian::Stopper;
 use Search::Xapian::TermIterator;
 use Search::Xapian::ValueIterator;
 use Search::Xapian::WritableDatabase;
+use Search::Xapian::Weight;
+use Search::Xapian::BM25Weight;
+use Search::Xapian::BoolWeight;
 
 require Exporter;
 require DynaLoader;
@@ -50,10 +53,15 @@ our %EXPORT_TAGS = (
                                  DB_CREATE
                                  DB_CREATE_OR_OPEN
                                  DB_CREATE_OR_OVERWRITE
+                                 ) ],
+                    'enq_order' => [ qw(
+				 ENQ_DESCENDING
+				 ENQ_ASCENDING
+				 ENQ_DONT_CARE
                                  ) ]
                    );
 $EXPORT_TAGS{standard} = [ @{ $EXPORT_TAGS{'ops'} }, @{ $EXPORT_TAGS{'db'} } ];
-$EXPORT_TAGS{all} = [ @{ $EXPORT_TAGS{'standard'} } ];
+$EXPORT_TAGS{all} = [ @{ $EXPORT_TAGS{'standard'}  }, @{ $EXPORT_TAGS{'enq_order'} } ];
 
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
@@ -124,6 +132,76 @@ be found on the Xapian web site).
 
 None by default.
 
+=head1 :db
+
+=over 4
+
+=item DB_OPEN
+
+Open a database, fail if database doesn't exist.
+
+=item DB_CREATE
+
+Create a new database, fail if database exists.
+
+=item DB_CREATE_OR_OPEN
+
+open the existing database, without destorying data, or create new.
+
+=item DB_CREATE_OR_OVERWRITE
+
+overwrite database if it exists
+
+=back
+
+=head1 :ops
+
+=over 4
+
+=item OP_AND
+
+Match if both subqueries are satisfied
+
+=item OP_OR
+
+Match if either subquery is satisfied.
+
+=item OP_AND_NOT
+
+Match if left but not right subquery is satisfied.
+
+=item OP_XOR
+
+Match if left or right, but not both queries are satisfied.
+
+=item OP_AND_MAYBE
+
+Match if left is satisfied, but use weights from both.
+
+=item OP_FILTER
+
+Like OP_AND, but only weight using the left query.
+
+=item OP_NEAR
+
+Match if the words are near eachother. The window should be specified, as
+a parameter to C<Search::Xapian::Query::Query>. but it defaults to the 
+number of terms in the list.
+
+=item OP_PHRASE
+
+Match as a phrase (All words in order).
+
+=item OP_ELITE_SET
+
+Select an elite set from the subqueries, and perform a query with these combined as an OR query. 
+
+=back
+
+=head1 :standard
+
+Standard is db + ops
+
 =head1 TODO
 
 =over 4
@@ -152,6 +230,8 @@ Enquire::set_weighting_scheme(const Weight &weight);
 Query::Query(tname, ...); with more than one argument;
 QueryParser::set_stemming_options() with third (Stopper) argument;
 
+=back
+
 =head1 CREDITS
 
 Thanks to Tye McQueen E<lt>tye@metronet.comE<gt> for explaining the
